@@ -10,6 +10,14 @@ test_that("Cities function can take multiple kinds of input", {
   expect_message(us_cities())
 })
 
-test_that("Cities function returns a data frame", {
+test_that("Cities function returns an sf data.frame", {
   expect_is(us_cities(1876), "data.frame")
+  expect_is(us_cities(1976), "sf")
+})
+
+test_that("Cities function can be filtered by state", {
+  nc <- us_cities(2010, states = "NC")
+  sc <- us_cities(1876, states = "South Carolina")
+  expect_identical(unique(nc$state_name), "North Carolina")
+  expect_identical(unique(sc$state_abbr), "SC")
 })
